package com.mdd.admin.service.impl;

import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.mdd.admin.service.ISettingPaymentService;
import com.mdd.admin.validate.setting.SettingPayConfigValidate;
import com.mdd.admin.validate.setting.SettingPayMethodValidate;
import com.mdd.admin.vo.setting.SettingPaymentMethodVo;
import com.mdd.common.entity.setting.DevPayConfig;
import com.mdd.common.entity.setting.DevPayWay;
import com.mdd.common.enums.PaymentEnum;
import com.mdd.common.mapper.setting.DevPayConfigMapper;
import com.mdd.common.mapper.setting.DevPayWayMapper;
import com.mdd.common.util.MapUtils;
import com.mdd.common.util.UrlUtils;
import java.util.Arrays;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import javax.annotation.Resource;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.Assert;

@Service
public class SettingPaymentServiceImpl implements ISettingPaymentService {
   @Resource
   DevPayConfigMapper devPayConfigMapper;
   @Resource
   DevPayWayMapper devPayWayMapper;

   public List<List<SettingPaymentMethodVo>> method() {
      List<DevPayWay> lists = this.devPayWayMapper.selectList((Wrapper)null);
      List<List<SettingPaymentMethodVo>> result = new LinkedList();
      List<SettingPaymentMethodVo> mnp = new LinkedList();
      List<SettingPaymentMethodVo> oa = new LinkedList();
      List<SettingPaymentMethodVo> h5 = new LinkedList();
      Iterator var6 = lists.iterator();

      while(var6.hasNext()) {
         DevPayWay devPayWay = (DevPayWay)var6.next();
         DevPayConfig devPayConfig = (DevPayConfig)this.devPayConfigMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).eq("id", devPayWay.getPayConfigId())).last("limit 1"));
         SettingPaymentMethodVo vo = new SettingPaymentMethodVo();
         BeanUtils.copyProperties(devPayWay, vo);
         vo.setName(PaymentEnum.getPayWayMsg(devPayConfig.getWay()));
         vo.setShowName(devPayConfig.getName());
         vo.setIcon(UrlUtils.toAbsoluteUrl(devPayConfig.getIcon()));
         switch (devPayWay.getScene()) {
            case 1:
               mnp.add(vo);
               break;
            case 2:
               oa.add(vo);
               break;
            case 3:
               h5.add(vo);
         }
      }

      result.add(mnp);
      result.add(oa);
      result.add(h5);
      return result;
   }

   public List<DevPayConfig> list() {
      List<DevPayConfig> devPayConfigs = this.devPayConfigMapper.selectList((Wrapper)(new QueryWrapper()).orderByDesc(Arrays.asList("sort", "id")));
      Iterator var2 = devPayConfigs.iterator();

      while(var2.hasNext()) {
         DevPayConfig dev = (DevPayConfig)var2.next();
         dev.setShowName(dev.getName());
         dev.setName(PaymentEnum.getPayWayMsg(dev.getWay()));
         dev.setParams(MapUtils.jsonToMap("{}"));
         dev.setIcon(UrlUtils.toAbsoluteUrl(dev.getIcon()));
      }

      return devPayConfigs;
   }

   public DevPayConfig detail(Integer id) {
      DevPayConfig devPayConfig = (DevPayConfig)this.devPayConfigMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).eq("id", id)).last("limit 1"));
      devPayConfig.setName(PaymentEnum.getPayWayMsg(devPayConfig.getWay()));
      devPayConfig.setShowName(devPayConfig.getName());
      devPayConfig.setParams(MapUtils.jsonToMap(devPayConfig.getParams().toString()));
      devPayConfig.setIcon(UrlUtils.toAbsoluteUrl(devPayConfig.getIcon()));
      return devPayConfig;
   }

   public void editConfig(SettingPayConfigValidate configValidate) {
      DevPayConfig devPayConfig = (DevPayConfig)this.devPayConfigMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).eq("id", configValidate.getId())).last("limit 1"));
      Assert.notNull(devPayConfig, "数据不存在!");
      devPayConfig.setName(configValidate.getName());
      devPayConfig.setIcon(UrlUtils.toRelativeUrl(configValidate.getIcon()));
      devPayConfig.setSort(configValidate.getSort());
      devPayConfig.setRemark(configValidate.getRemark());
      if (devPayConfig.getWay().equals(1)) {
         devPayConfig.setParams("{}");
      } else {
         devPayConfig.setParams(JSON.toJSONString(configValidate.getParams()));
      }

      this.devPayConfigMapper.updateById(devPayConfig);
   }

   @Transactional
   public void editMethod(SettingPayMethodValidate methodValidate) {
      List<List<SettingPaymentMethodVo>> data = methodValidate.getData();
      Iterator var3 = data.iterator();

      while(var3.hasNext()) {
         List<SettingPaymentMethodVo> list = (List)var3.next();
         Iterator var5 = list.iterator();

         while(var5.hasNext()) {
            SettingPaymentMethodVo vo = (SettingPaymentMethodVo)var5.next();
            DevPayWay way = new DevPayWay();
            way.setIsDefault(vo.getIsDefault());
            way.setStatus(vo.getStatus());
            this.devPayWayMapper.update(way, (Wrapper)(new QueryWrapper()).eq("id", vo.getId()));
         }
      }

   }
}
